@@ -1,6 +1,6 @@
 use common::sense;
 
-our $VERSION = '0.991';
+our $VERSION = '1.0';
 
 # ABSTRACT: Work with a deck of playing cards in the fashion engineered by Duane O'Brien of I.B.M. developerWorks.
 
@@ -162,6 +162,7 @@ Helper::Deck - Work with a deck of playing cards in the fashion engineered by Du
 =cut
 
 =head1 SYNOPSIS
+
     use common::sense;
     use Helper::Deck;
     
@@ -196,32 +197,17 @@ Helper::Deck - Work with a deck of playing cards in the fashion engineered by Du
     print "The dealer gave himself ", $d1->card_to_string($deal1->[4]), "\n";
     
     my $odds = $d1->calculate_odds($deck1, $tc);
-    
+
 =cut
 
 =head1 INTRODUCTION
 
-Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam scelerisque id nunc nec volutpat. Etiam pellentesque tristique arcu, non consequat magna fermentum ac. Cras ut ultricies eros. Maecenas eros justo, ullamcorper a sapien id, viverra ultrices eros. Morbi sem neque, posuere et pretium eget, bibendum sollicitudin lacus. Aliquam eleifend sollicitudin diam, eu mattis nisl maximus sed. Nulla imperdiet semper molestie. Morbi massa odio, condimentum sed ipsum ac, gravida ultrices erat. Nullam eget dignissim mauris, non tristique erat. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae;
+Work with a deck of playing cards in the fashion engineered by Duane O'Brien of I.B.M. developerWorks.
 
 =cut
 
 =head1 METHODS
 
-=head2 method1
-    usage :
-    
-        Parameters : 
-            Let a1 be argument one,
-            Let a2 be argument two,
-        Results :
-            Let r be description of return value,
-            
-        my $r = $obj->method1($a1, $a2);
-
-Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam scelerisque id nunc nec volutpat. Etiam pellentesque tristique arcu, non consequat magna fermentum ac. Cras ut ultricies eros. Maecenas eros justo, ullamcorper a sapien id, viverra ultrices eros. Morbi sem neque, posuere et pretium eget, bibendum sollicitudin lacus. Aliquam eleifend sollicitudin diam, eu mattis nisl maximus sed. Nulla imperdiet semper molestie. Morbi massa odio, condimentum sed ipsum ac, gravida ultrices erat. Nullam eget dignissim mauris, non tristique erat. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae;
-
-=cut
-
 =head2 roll
     usage :
     
